These functions (summarize_weighted_production() and summarize_weighted_percent_change()) were deprecated because they are not required as a user-facing function for PACTA for Banks. They are still used internally though. All relevant outputs of the PACTA for Banks analysis can be obtained using the target_market_share() and target_sda() functions.
Based on on the weight of each loan per sector per year,
summarize_weighted_production() and summarize_weighted_percent_change()
summarize the production and percent-change, respectively.
summarize_weighted_production(data, ..., use_credit_limit = FALSE)summarize_weighted_percent_change(data, ..., use_credit_limit = FALSE)
A tibble with the same groups as the input (if any) and columns:
sector, technology, and year; and weighted_production or
weighted_production for summarize_weighted_production() and
summarize_weighted_percent_change(), respectively.
A data frame like the output of join_abcd_scenario().
Variables to group by.
Logical vector of length 1. FALSE defaults to using
the column loan_size_outstanding. Set to TRUE to instead use the column
loan_size_credit_limit.
The percent-change analysis excludes companies with 0 production. percent-change is undefined for companies that have no initial production; including such companies would cause percent-change percentage to be infinite, which is wrong.
join_abcd_scenario().
Other utility functions:
join_abcd_scenario()