This function calculates the portfolio-level production targets, as calculated using the market share approach applied to each relevant climate production forecast.
target_market_share(
data,
abcd,
scenario,
region_isos = r2dii.data::region_isos,
use_credit_limit = FALSE,
by_company = FALSE,
weight_production = TRUE,
increasing_or_decreasing = r2dii.data::increasing_or_decreasing
)A tibble including the summarized columns metric, production,
technology_share, percentage_of_initial_production_by_scope and
scope. If by_company = TRUE, the output will also have the column
name_abcd.
A "data.frame" like the output of r2dii.match::prioritize.
An asset level data frame like r2dii.data::abcd_demo.
A scenario data frame like r2dii.data::scenario_demo_2020.
A data frame like r2dii.data::region_isos (default).
Logical vector of length 1. FALSE defaults to using
the column loan_size_outstanding. Set to TRUE to use the column
loan_size_credit_limit instead.
Logical vector of length 1. FALSE defaults to outputting
production_value at the portfolio-level. Set to TRUE to output
production_value at the company-level.
Logical vector of length 1. TRUE defaults to
outputting production, weighted by relative loan-size. Set to FALSE to
output the unweighted production values.
A data frame like r2dii.data::increasing_or_decreasing.
This function ignores existing groups and outputs ungrouped data.
Other functions to calculate scenario targets:
target_sda()